web/formwidgets.py
branchstable
changeset 7879 9aae456abab5
parent 7453 84046395d2cd
child 7990 a673d1d9a738
--- a/web/formwidgets.py	Tue Sep 27 16:04:30 2011 +0200
+++ b/web/formwidgets.py	Wed Sep 28 09:27:42 2011 +0200
@@ -110,8 +110,8 @@
 
     **Attributes**
 
-    Here are standard attributes of a widget, that may be set on concret
-    class to override default behaviours:
+    Here are standard attributes of a widget, that may be set on concrete class
+    to override default behaviours:
 
     :attr:`needs_js`
        list of javascript files needed by the widget.
@@ -134,7 +134,7 @@
 
     Also, widget instances takes as first argument a `attrs` dictionary which
     will be stored in the attribute of the same name. It contains HTML
     attributes that should be set in the widget's input tag (though concret
     classes may ignore it).
 
     .. currentmodule:: cubicweb.web.formwidgets
@@ -190,7 +190,7 @@
         return self._render(form, field, renderer)
 
     def _render(self, form, field, renderer):
         """This is the method you have to implement in concret widget classes.
         """
         raise NotImplementedError()
 
@@ -232,7 +232,7 @@
         correctly typed value.
 
         3 and 4 are handle by the :meth:`typed_value` method to ease reuse in
-        concret classes.
+        concrete classes.
         """
         values = None
         if not field.ignore_req_params:
@@ -134,7 +134,7 @@
     Also, widget instances takes as first argument a `attrs` dictionary which
     will be stored in the attribute of the same name. It contains HTML
-    attributes that should be set in the widget's input tag (though concret
+    attributes that should be set in the widget's input tag (though concrete
     classes may ignore it).
 
@@ -190,7 +190,7 @@
 
     def _render(self, form, field, renderer):
-        """This is the method you have to implement in concret widget classes.
+        """This is the method you have to implement in concrete widget classes.
         """
         raise NotImplementedError()